<template>
  <div class="page">
    <div class="info">
      <div class="detail">
        <span class="label"><img width="40" height="40" :src="require('@/assets/images/mapSearch/搜地址.png')" /></span>
        <span class="value">&nbsp;{{ company.name }}</span>
      </div>
      <div class="detail">
        <span class="label">法定代表人：</span>
        <span class="value">{{ company.legal }}</span>
      </div>
      <div class="detail">
        <span class="label">联系方式：</span>
        <span v-if="!concatVisible" class="value">{{ company.contactHide }}</span>
        <span v-if="concatVisible" class="value">{{ company.legalContact }}</span>
        <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
      </div>
      <div class="detail">
        <span class="label">注册地址：</span>
        <span class="value">{{ company.registerAddress }}</span>
      </div>
      <div class="detail">
        <span class="label">驻勤点数：</span>
        <span class="value">{{ company.countOfActivityStation }}</span>
      </div>
      <div class="detail">
        <span class="label">保安员数：</span>
        <span class="value">{{ company.countOfSecurityMan }}</span>
      </div>
    </div>
  </div>
</template>

<script>
import { getCompanyDetail } from "@/api/company-controller";
import { textSlice } from "@/api/common";

export default {
  name: "CompanyInfo",
  data() {
    return {
      company: {},
      concatVisible: false,
    };
  },
  computed: {
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
    queryId() {
      return this.$route.query.queryId;
    },
  },
  watch: {
    queryId: {
      handler(newVal, OldVal) {
        if (newVal && newVal !== OldVal) {
          this.toCompany();
        }
      },
      immediate: true,
    },
  },
  methods: {
    /**
     * @企业详情
     */
    toCompany() {
      getCompanyDetail(this.queryId)
        .then((company) => {
          console.log("company", company);
          const { registerAddress, legalContact } = company;
          this.company = {
            ...{
              registerAddressSlice: textSlice(registerAddress),
              contactHide: this.parseStringToStar(legalContact),
            },
            ...company,
          };
        })
        .catch((err) => {
          console.log(err);
        });
    },
    parseStringToStar(str) {
      return "**************";
      // return str.length > 2 ? str.substr(0, 2) + new Array(str.length - 2).join("*") + str.substr(-2) : str;
    },
  },
};
</script>

<style scoped lang="less">
.page {
  .info {
    width: 100%;
    padding: 12px 20px;
    .return {
      font-size: 12px;
      font-family: PingFang SC-Regular, PingFang SC, serif;
      font-weight: 400;
      color: #0f71ff;
      line-height: 22px;
      margin-bottom: 10px;
    }
    .detail {
      width: 100%;
      display: flex;
      align-items: center;
      margin-bottom: 10px;
      &:last-child {
        margin-bottom: 0;
      }
      .label {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #909399;
      }

      .value {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #303133;
        &-link {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #0f71ff;
          text-decoration: underline;
        }
      }
      .visible {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #0f71ff;
        margin-left: 2px;
      }
    }
  }
}
</style>
